package at.ac.uibk.gitsearch.service;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.jupiter.api.Test;

public class ShoppingBasketServiceTest {

	@Test
	public void simpleFilterOutTests() {
		assertFalse(ShoppingBasketService.filterOut("someFile.txt",
				new String[]{}, false));
		assertFalse(ShoppingBasketService.filterOut("someFile.txt",
				new String[]{"some"}, false));
		assertTrue(ShoppingBasketService.filterOut("someFile.txt",
				new String[]{"some*"}, false));
		assertFalse(ShoppingBasketService.filterOut("someFile.txt",
				new String[]{"some*.pdf"}, false));
		assertTrue(ShoppingBasketService.filterOut("someFile.txt",
				new String[]{"some*.txt"}, false));
	}
	@Test
	public void filterOutTestsWithLeadingRoot() {
		assertFalse(ShoppingBasketService.filterOut("/someFile.txt",
				new String[]{}, false));
		assertFalse(ShoppingBasketService.filterOut("/someFile.txt",
				new String[]{"**/some"}, false));
		assertTrue(ShoppingBasketService.filterOut("/someFile.txt",
				new String[]{"**/some*"}, false));
		assertFalse(ShoppingBasketService.filterOut("/someFile.txt",
				new String[]{"**/some*.pdf"}, false));
		assertTrue(ShoppingBasketService.filterOut("/someFile.txt",
				new String[]{"**/some*.txt"}, false));
	}

	@Test
	public void filterOutTestsWithDirectories() {
		assertFalse(ShoppingBasketService.filterOut("someDir", new String[]{},
				true));
		assertFalse(ShoppingBasketService.filterOut("someDir",
				new String[]{"some/"}, true));
		assertTrue(ShoppingBasketService.filterOut("someDir",
				new String[]{"/some*"}, true));
		assertTrue(ShoppingBasketService.filterOut("someDir",
				new String[]{"some*"}, true));
		assertTrue(ShoppingBasketService.filterOut("someDir/",
				new String[]{"some*/"}, true));
		assertFalse(ShoppingBasketService.filterOut("someDir",
				new String[]{"*/some/"}, true));
		assertFalse(ShoppingBasketService.filterOut("parent/someDir",
				new String[]{"*/some/"}, true));
		assertFalse(ShoppingBasketService.filterOut("parent/someDir",
				new String[]{"someDir/"}, true));
		assertTrue(ShoppingBasketService.filterOut("parent/someDir",
				new String[]{"**/someDir"}, true));
		assertTrue(ShoppingBasketService.filterOut("parent/someDir",
				new String[]{"**/some*"}, true));

	}
}
